@@ -2,7 +2,6 @@ import numpy as np
 import pandas as pd
 from abc import ABC, abstractmethod
 from collections import Counter
-
 from recsyslearn.errors import SegmentationNotSupportedException, WrongProportionsException
 
 
@@ -14,17 +13,13 @@ class Segmentation(ABC):
     def __init__(self) -> None:
         super().__init__()
 
-    @abstractmethod
-    def segment(self, dataset: pd.DataFrame) -> None:
-        pass
-
 
 class InteractionSegmentation(Segmentation):
     """
     Segmentation of items based on the number of interaction they have.
     """
 
-    def segment(self, dataset: pd.DataFrame, proportion: list = [0.8, 0.2], min_interaction: int = 0) -> pd.DataFrame:
+    def segment(self, dataset: pd.DataFrame, proportion=None, min_interaction: int = 0) -> pd.DataFrame:
 
         """
         Segmentation of items based on their interactions with different users.
@@ -38,6 +33,9 @@ class InteractionSegmentation(Segmentation):
         proportion : list, default [0.8, 0.2]
             The proportion of interactions wanted for every group. Its length should be between 1 and 3.
 
+        min_interaction : int, default 0
+            The minimum number of interaction. Items below this threshold will be removed.
+
 
         Raises
         ------
@@ -53,16 +51,22 @@ class InteractionSegmentation(Segmentation):
         DataFrame with items and belonging group.
         """
 
+        if proportion is None:
+            proportion = [0.8, 0.2]
+
         if len(proportion) not in (1, 2, 3):
             raise SegmentationNotSupportedException()
 
-        if sum(proportion) != 1:
+        if np.sum(proportion * 10) / 10 != 1:
             raise WrongProportionsException()
 
         if len(proportion) == 1:
             return dataset
 
-        item_groups = dataset.groupby('item').size().reset_index(name='count').sort_values('count', ascending=False)
+        item_groups = dataset.groupby('item')\
+            .size()\
+            .reset_index(name='count')\
+            .sort_values('count', ascending=False)
 
         tmp = item_groups[item_groups['count'] > min_interaction]
         n_int = tmp['count'].sum()
@@ -75,7 +79,8 @@ class InteractionSegmentation(Segmentation):
         mid_tail = tmp.loc[tmp['cumulative_sum'].lt(mid_thr) & ~tmp['item'].isin(short_head), 'item']
         conditions = [item_groups['item'].isin(short_head), item_groups['item'].isin(mid_tail)]
         choices = ['1', '2']
-        item_groups.loc[:, 'group'] = np.select(conditions, choices, default='3' if len(proportion) == 3 else '2')
+        default = str(len(proportion))
+        item_groups.loc[:, 'group'] = np.select(conditions, choices, default=default)
         return item_groups[['item', 'group']]
 
 
@@ -96,28 +101,19 @@ class PopularityPercentage(Segmentation):
         group : str
             Whether to calculate the popularity of users or items
 
-
-        Raises
-        ------
-
-
         Return
         ------
         DataFrame with items/user and corresponding popularity.
         """
 
-        # Get the item column as a numpy array
         item_interactions = dataset[group].values
-        # Get the total number of user-item interactions
         total_interactions = len(item_interactions)
-
-        # Get the dictionary of {item_id: number_of_interactions}
         inter_counter = Counter(item_interactions)
-
-        # Convert the counts to percentages
         inter_counter = {item: counts / total_interactions for item, counts in inter_counter.items()}
 
-        popularity_dataframe = pd.DataFrame.from_dict(inter_counter, orient='index').reset_index()
+        popularity_dataframe = pd.DataFrame\
+            .from_dict(inter_counter, orient='index')\
+            .reset_index()
         popularity_dataframe.columns = [group, 'percentage']
 
         return popularity_dataframe
@@ -128,7 +124,7 @@ class ActivitySegmentation(Segmentation):
     Segmentation of users based on their number of interaction.
     """
 
-    def segment(self, dataset: pd.DataFrame, proportion: list = [0.1, 0.9], min_interaction: int = 0) -> pd.DataFrame:
+    def segment(self, dataset: pd.DataFrame, proportion=None, min_interaction: int = 0) -> pd.DataFrame:
 
         """
         Segmentation of users based on their interactions with different items.
@@ -142,6 +138,9 @@ class ActivitySegmentation(Segmentation):
         proportion : list, default [0.8, 0.2]
             The proportion of interactions wanted for every group.
 
+        min_interaction : int, default 0
+            The minimum number of interaction. Users below this threshold will be removed.
+
 
         Raises
         ------
@@ -157,10 +156,13 @@ class ActivitySegmentation(Segmentation):
         DataFrame with users and belonging group.
         """
 
+        if proportion is None:
+            proportion = [0.1, 0.9]
+
         if len(proportion) not in (1, 2, 3):
             raise SegmentationNotSupportedException()
 
-        if sum(proportion) != 1:
+        if np.sum(proportion * 10) / 10 != 1:
             raise WrongProportionsException()
 
         if len(proportion) == 1:
@@ -173,8 +175,8 @@ class ActivitySegmentation(Segmentation):
         user_groups.loc[:, 'count'] = user_groups.loc[:, 'count'].apply(lambda x: x + np.random.choice(list(range(10))))
         user_groups = user_groups.sort_values('count', ascending=False)
         user_groups.loc[:, 'count'] = np.arange(user_groups.shape[0]) + 1
-        threshold = round(user_groups.shape[0] * proportion[0]) if round(
-            user_groups.shape[0] * proportion[0]) > 0 else 1
+        threshold = round(user_groups.shape[0] * proportion[0])\
+            if round(user_groups.shape[0] * proportion[0]) > 0 else 1
 
         user_groups.loc[user_groups['count'] <= threshold, 'group'] = '1'
         user_groups.loc[user_groups['count'] > threshold, 'group'] = '2'
