@@ -1,24 +1,25 @@
 import pandas as pd
 import numpy as np
+from pandas import DataFrame
 
 from recsyslearn.errors import ColumnsNotMatchException
 
 
-def test_pattern(input: pd.DataFrame, pattern: list) -> None:
+def test_pattern(df: pd.DataFrame, pattern: list) -> DataFrame:
 
     """
     Raise ColumnsNotMatchException if pd.Dataframe header is not as expected.
 
     Parameters
     ----------
-    input : pd.DataFrame
+    df : pd.DataFrame
       Input that should be tested.
 
     pattern : list
       pd.DataFrame column pattern that should be matched. (a header).
 
 
-    Raise
+    Raises
     ------
     ColumnsNotMatchException
       If input as not expected.
@@ -29,7 +30,7 @@ def test_pattern(input: pd.DataFrame, pattern: list) -> None:
     Converted columns within the same DataFrame.
     """
 
-    if list(input.columns) != pattern:
+    if list(df.columns) != pattern:
         raise ColumnsNotMatchException(pattern)
 
     dtypes = {
@@ -40,8 +41,8 @@ def test_pattern(input: pd.DataFrame, pattern: list) -> None:
         "target_representation": float,
     }
 
-    return input.astype(
-        {col: dtypes[col] for col in input.columns if col in dtypes.keys()}
+    return df.astype(
+        {col: dtypes[col] for col in df.columns if col in dtypes.keys()}
     )
 
 
@@ -56,10 +57,10 @@ def exp_matrix(top_n: pd.DataFrame) -> pd.DataFrame:
         Recommendation lists per user in the form (user, item, rank, group).
 
 
-    Raise
+    Raises
     -----
     ColumnsNotMatchException
-        If top_n is not in the from (user, item, rank, group).
+        If top_n is not in the form (user, item, rank, group).
 
 
     Return
@@ -91,10 +92,10 @@ def prob_matrix(top_n: pd.DataFrame) -> pd.DataFrame:
         The DataFrame with computed probability distribution.
 
 
-    Raise
-    -----
+    Raises
+    ------
     ColumnsNotMatchException
-        If top_n is not in the from (user, item, rank, group).
+        If top_n is not in the form (user, item, rank, group).
     """
 
     test_pattern(top_n, ["user", "item", "rank", "group"])
@@ -113,6 +114,9 @@ def eff_matrix(top_n: pd.DataFrame, rel_matrix: pd.DataFrame) -> pd.DataFrame:
     top_n : pd.DataFrame
         Recommendation lists per user in the form (user, item, rank, group).
 
+    rel_matrix : pd.DataFrame
+        Dataframe containing relevant items for every user.
+
 
     Return
     ------
@@ -132,8 +136,6 @@ def eff_matrix(top_n: pd.DataFrame, rel_matrix: pd.DataFrame) -> pd.DataFrame:
 
     top_n = exp_matrix(top_n)
     top_n = top_n.merge(rel_matrix, on=["user", "item", "group"], how="outer")
-    top_n.loc[:, ["rank_x", "rank_y"]] = top_n.loc[
-        :, ["rank_x", "rank_y"]
-    ].fillna(0)
+    top_n.loc[:, ["rank_x", "rank_y"]] = top_n.loc[:, ["rank_x", "rank_y"]].fillna(0)
     top_n["rank"] = top_n["rank_x"] * top_n["rank_y"]
     return top_n[["user", "item", "rank", "group"]]
